<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>default</source>
        <translation>défaut</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <source>Icons</source>
        <translation>Icônes</translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation>Émoticônes</translation>
    </message>
    <message>
        <source>Enable emoticons</source>
        <translation>Activer émoticônes</translation>
    </message>
    <message>
        <source>Animate emoticons</source>
        <translation>Émoticônes animés</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Thème d&apos;icônes</translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation>Choisir thème émoticônes</translation>
    </message>
    <message>
        <source>Install new emoticons...</source>
        <translation>Installer de nouvelles émoticônes...</translation>
    </message>
</context>
<context>
    <name>EmoticonsConfigurationUiHandler</name>
    <message>
        <source>Open icon theme archive</source>
        <translation>Ouvrir thème d&apos;émoticône depuis une archive</translation>
    </message>
    <message>
        <source>Installation failed</source>
        <translation>Installation échoué</translation>
    </message>
    <message>
        <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
        <translation>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</translation>
    </message>
</context>
<context>
    <name>InsertEmoticonAction</name>
    <message>
        <source>Insert Emoticon</source>
        <translation>Insérer Émoticône</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Insérer émoticône</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Insérer émoticône - activer dans configuration</translation>
    </message>
</context>
</TS>